@@ -57,7 +57,7 @@ test_checkpoint <- function(https = FALSE, snap.dates){
         it("finds correct MRAN URL", {
           expect_equal(
             getSnapshotUrl(snap_date),
-            paste0(url_prefix, "mran.revolutionanalytics.com/snapshot/", snap_date))
+            paste0(url_prefix, "mran.microsoft.com/snapshot/", snap_date))
           
         })
         
@@ -104,22 +104,6 @@ test_checkpoint <- function(https = FALSE, snap.dates){
                                                               lib.loc = .Library,
                                                               noCache = TRUE))
           
-          pkgDepends <- function (pkg) {
-            depMtrx <- tools:::getDepMtrx(pkg, instPkgs = pdbMRAN, local = FALSE)
-            if (is.null(depMtrx)){
-              stop(gettextf("package '%s' was not found", pkg), domain = NA)
-            }
-            tools::getDepList(depMtrx, pdbMRAN)
-          }
-          
-          packages.expected <- sort(unique(unlist(
-            sapply(setdiff(packages.to.test, c("checkpoint", base.packages)), function(p){
-              z <- pkgDepends(p)
-              c(z$Depends, z$Imports)
-            }, USE.NAMES = FALSE)
-          )))
-          
-          
           expected.packages <- setdiff(packages.to.test, c("checkpoint", base.packages))
           
           expect_true(
@@ -148,24 +132,11 @@ test_checkpoint <- function(https = FALSE, snap.dates){
           )
           
         })
-        #       expect_true(
-        #         all(
-        #           sapply(setdiff(packages.to.test, "checkpoint"), function(x){
-        #             if(!base::requireNamespace(x, quietly = TRUE)) {
-        #               message(paste("Unable to load package:", x))
-        #               FALSE
-        #           } else {
-        #             unloadNamespace(x)
-        #             TRUE
-        #           }
-        #           })
-        #         )
-        #       )
-        
+
         it("uses correct MRAN url", {
           expect_equal(
             getOption("repos"),
-            paste0(url_prefix, "mran.revolutionanalytics.com/snapshot/", snap_date)
+            paste0(url_prefix, "mran.microsoft.com/snapshot/", snap_date)
           )
         })
         
@@ -198,14 +169,14 @@ initialUrl <- getOption("checkpoint.mranUrl")
 if(getRversion() >= "3.2.0" && httpsSupported()){
   context("https")
   
-  options(checkpoint.mranUrl = "https://mran.revolutionanalytics.com/")
+  options(checkpoint.mranUrl = "https://mran.microsoft.com/")
   test_checkpoint(http = TRUE, snap.dates = MRAN.default)
   
   options(checkpoint.mranUrl = NULL)
 }
 
 context("http")
-options(checkpoint.mranUrl = "http://mran.revolutionanalytics.com/")
+options(checkpoint.mranUrl = "http://mran.microsoft.com/")
 test_checkpoint(http = FALSE, snap.dates = MRAN.default)
 options(checkpoint.mranUrl = initialUrl)
 
